![](docs/_static/logo.png)

A Python package and command line utility for annotating the local ancestral sequence context of biallelic SNPs

[![build and test](https://github.com/harrispopgen/mutyper/actions/workflows/build-and-test.yml/badge.svg)](https://github.com/harrispopgen/mutyper/actions/workflows/build-and-test.yml)
[![Docs build and deploy](https://github.com/harrispopgen/mutyper/actions/workflows/docs-build-and-deploy.yml/badge.svg)](https://github.com/harrispopgen/mutyper/actions/workflows/docs-build-and-deploy.yml)
[![Python package](https://github.com/harrispopgen/mutyper/actions/workflows/python-publish.yml/badge.svg)](https://github.com/harrispopgen/mutyper/actions/workflows/python-publish.yml)

#### See [documentation](https://harrispopgen.github.io/mutyper) for install and usage information.

Pairs well with the package [`mushi`](https://github.com/harrispopgen/mushi), which performs mutation spectrum history inference.
